==> campsite-2.4.1.tar.gz: campsite/implementation/management/priv/lang/de/issues.php <==
<?php
regGS("Issue List", "Liste der Ausgaben");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Name (zum Betrachten der Rubrik anklicken)");
regGS("Published<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Veröffentlicht (jjjj-mm-tt)");
regGS("Delete issue $1", "Ausgabe $1 löschen");
regGS("Publish articles", "Artikel veröffentlichen");
regGS("Change issue status", "Status der Ausgabe ändern");
regGS("You do not have the right to change issues.", "Keine Berechtigung Ausgaben zu ändern");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Ausgabe $1 wirklich von $2 auf $3 ändern?");
regGS("Add new translation", "Übersetzung hinzufügen");
regGS("You do not have the right to add issues.", "Keine Berechtigung Ausgaben hinzuzufügen");
regGS("The issue $1 has been successfuly added.", "Ausgabe $1 wurde hinzugefügt");
regGS("The issue could not be added.", "Die Ausgabe konnte nicht verändert werden");
regGS("Please check if another issue with the same number/language does not already exist.", "Bitte überprüfen, ob weitere Ausgabe mit derselben Nummer/Sprache bereits existiert");
regGS("Change issue details", "Details der Ausgabe ändern");
regGS("You do not have the right to change issue details.", "Keine Rechte Details der Ausgabe zu ändern");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publikationsdatumg<br><small>(yyyy-mm-tt)</small>");
regGS("Front Page Template", "Template der Startseite");
regGS("Issue $1 updated in publication $2", "Ausgabe $1 in Publikation $2 wurde geändert");
regGS("You do not have the right to delete issues.", "Keine Berechtigung Ausgaben zu löschen");
regGS("Are you sure you want to delete the issue $1?", "Ausgabe $1 wirklich löschen?");
regGS("Deleting issue", "Ausgabe wird gelöscht");
regGS("Use the structure of the previous issue", "Die Struktur der vorherigen Ausgabe verwenden");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Die Struktur der letzten Ausgabe in allen Sprachen kopieren - ohne Inhalte");
regGS("You may modify it later if you wish.", "Veränderungen können später vorgenommen werden");
regGS("Create a new structure", "Neue Struktur anlegen");
regGS("Create a complete new structure.", "Völlig neue Struktur anlegen");
regGS("You must define an issue type for each language and then sections for them.", "Bitte einen Ausgabentyp pro Sprache und Rubrik definieren");
regGS("Copy previous issue", "Vorherige Ausgabe kopieren");
regGS("No previous issue.", "Keine vorherige Ausgabe vorhanden");
regGS("Copy structure from issue nr $1", "Struktur der Ausgabe $1 kopieren");
regGS("Copying previous issue", "Vorherige Ausgabe kopieren");
regGS("Select the issue", "Ausgabe auswählen");
regGS("New issue $1 from $2 in publication $3", "Neue Ausgabe $1 von $2 der Publikation $3");
regGS("Adding new issue", "Neue Ausgabe hinzufügen");
regGS("Delete entry", "Eintrag löschen");
regGS("Issue Publishing Schedule", "Veröffentlichung der Ausgabe automatisieren");
regGS("Invalid Input: $1", "Ungültige Eingabe: $1");
regGS("Issue Number", "Ausgabennummer");
regGS("Go To Sections", "Gehe zu den Rubriken");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Template der Startseite");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Template für Artikel");
regGS("Changing issue status", "Status der Ausgabe wird geändert");
regGS("Status of the issue $1 has been changed from $2 to $3", "Status der Ausgabe $1 wurde von $2 auf $3 geändert");
regGS("Status of the issue $1 could not be changed.", "Status der Ausgabe $1 konnte nicht verändert werden");
regGS("Updating issue", "Ausgabe wird verändert");
regGS("Changing issue's details", "Details der Ausgabe verändern");
regGS("The issue $1 has been successfuly changed.", "Ausgabe $1 wurde geändert");
regGS("The issue could not be changed.", "Die Ausgabe konnte nicht verändert werden");
regGS("Preview issue", "Vorherige Ausgabe");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Diese Ausgabe kann in der Vorschau nicht angezeigt werden. Bitter sicherstellen, dass Template $1 gewählt wurde");
regGS("front page", "Startseite");
regGS("Changing issue template", "Template der Ausgabe ändern");
regGS("You do not have the right to change issue templates.", "Keine Berechtigung Templates der Ausgabe zu ändern");
regGS("Changing issue template for front page", "Template der Startseite ändern");
regGS("Changing issue template for single article", "Template der Artikel ändern");
regGS("The template has been successfully changed.", "Die Template wurde verändert");
regGS("Issue template for publication $1 changed to $2", "Template der Ausgabe in Publikation $1 nach $2 geändert");
regGS("Issue template for single articles from $1 changed to $2", "Template der Ausgabe für Artikel $1 nach $2 geändert");
regGS("The template could not be changed.", "Die Template konnte nicht geändert werden");
?>

==> campsite-2.6.6.tar.gz: campsite/implementation/management/priv/lang/de/issues.php <==
<?php 
regGS("Change issue status", "");
regGS("The values you are trying to set conflict with issue \"$1$2. $3 ($4)$5\".", "");
regGS("The number must be unique for each issue in this publication of the same language.", "");
regGS("The language and URL name must be unique for each issue in this publication.", "");
regGS("Issue created.", "");
regGS("Issue updated", "");
regGS("Could not save the changes to the issue.", "");
regGS("Unpublish on: $1", "");
regGS("There are $1 articles in this issue.", "");
regGS("The issue $1 has been deleted.", "");
regGS("Schedule", "");
regGS("Publish on: $1", "");
regGS("Publish Date $1", "");
regGS("Deleted issue", "");
regGS("Delete issue", "");
regGS("Click here to publish this issue", "");
regGS("A total of $1 articles were deleted.", "");
regGS("Name<BR><SMALL>(click to see sections)</SMALL>", "Name (zum Betrachten der Rubrik anklicken)");
regGS("Delete issue $1", "Ausgabe $1 löschen");
regGS("Publish articles", "Artikel veröffentlichen");
regGS("You do not have the right to change issues.", "Keine Berechtigung Ausgaben zu ändern");
regGS("Are you sure you want to change the issue $1 status from $2 to $3?", "Ausgabe $1 wirklich von $2 auf $3 ändern?");
regGS("Add new translation", "Übersetzung hinzufügen");
regGS("You do not have the right to add issues.", "Keine Berechtigung Ausgaben hinzuzufügen");
regGS("The issue $1 has been successfuly added.", "Ausgabe $1 wurde hinzugefügt");
regGS("The issue could not be added.", "Die Ausgabe konnte nicht verändert werden");
regGS("Change issue details", "Details der Ausgabe ändern");
regGS("You do not have the right to change issue details.", "Keine Rechte Details der Ausgabe zu ändern");
regGS("Publication date<BR><SMALL>(yyyy-mm-dd)</SMALL>", "Publikationsdatumg<br><small>(yyyy-mm-tt)</small>");
regGS("Front Page Template", "Template der Startseite");
regGS("Issue $1 updated in publication $2", "Ausgabe $1 in Publikation $2 wurde geändert");
regGS("You do not have the right to delete issues.", "Keine Berechtigung Ausgaben zu löschen");
regGS("Are you sure you want to delete the issue $1?", "Ausgabe $1 wirklich löschen?");
regGS("Use the structure of the previous issue", "Die Struktur der vorherigen Ausgabe verwenden");
regGS("Copy the entire structure in all languages from the previous issue except for content.", "Die Struktur der letzten Ausgabe in allen Sprachen kopieren - ohne Inhalte");
regGS("You may modify it later if you wish.", "Veränderungen können später vorgenommen werden");
regGS("Create a new structure", "Neue Struktur anlegen");
regGS("Create a complete new structure.", "Völlig neue Struktur anlegen");
regGS("You must define an issue type for each language and then sections for them.", "Bitte einen Ausgabentyp pro Sprache und Rubrik definieren");
regGS("Copy previous issue", "Vorherige Ausgabe kopieren");
regGS("No previous issue.", "Keine vorherige Ausgabe vorhanden");
regGS("Copy structure from issue number $1", "Struktur der Ausgabe $1 kopieren");
regGS("New issue $1 from $2 in publication $3", "Neue Ausgabe $1 von $2 der Publikation $3");
regGS("Delete entry", "Eintrag löschen");
regGS("Issue Publishing Schedule", "Veröffentlichung der Ausgabe automatisieren");
regGS("Invalid Input: $1", "Ungültige Eingabe: $1");
regGS("Issue Number", "Ausgabennummer");
regGS("Go To Sections", "Gehe zu den Rubriken");
regGS("Front Page Template<BR><SMALL>(click to change)</SMALL>", "Template der Startseite");
regGS("Single Article Template<BR><SMALL>(click to change)</SMALL>", "Template für Artikel");
regGS("Changing issue status", "Status der Ausgabe wird geändert");
regGS("Status of the issue $1 has been changed from $2 to $3", "Status der Ausgabe $1 wurde von $2 auf $3 geändert");
regGS("Status of the issue $1 could not be changed.", "Status der Ausgabe $1 konnte nicht verändert werden");
regGS("Updating issue", "Ausgabe wird verändert");
regGS("Changing issue's details", "Details der Ausgabe verändern");
regGS("The issue $1 has been successfuly changed.", "Ausgabe $1 wurde geändert");
regGS("The issue could not be changed.", "Die Ausgabe konnte nicht verändert werden");
regGS("Preview issue", "Vorherige Ausgabe");
regGS("This issue cannot be previewed. Please make sure it has a $1 template selected.", "Diese Ausgabe kann in der Vorschau nicht angezeigt werden. Bitter sicherstellen, dass Template $1 gewählt wurde");
regGS("front page", "Startseite");
regGS("Changing issue template", "Template der Ausgabe ändern");
regGS("You do not have the right to change issue templates.", "Keine Berechtigung Templates der Ausgabe zu ändern");
regGS("Changing issue template for front page", "Template der Startseite ändern");
regGS("Changing issue template for single article", "Template der Artikel ändern");
regGS("The template has been successfully changed.", "Die Template wurde verändert");
regGS("Issue template for publication $1 changed to $2", "Template der Ausgabe in Publikation $1 nach $2 geändert");
regGS("Issue template for single articles from $1 changed to $2", "Template der Ausgabe für Artikel $1 nach $2 geändert");
regGS("The template could not be changed.", "Die Template konnte nicht geändert werden");
regGS("There was an error reading the language parameter.", "Fehler beim Lesen der Spracheinstellung");
regGS("There was an error reading the publication parameter.", "Fehler beim Lesen der Publikationseinstellung");
regGS("There was an error reading the issue parameter.", "Fehler beim Lesen der Ausgabeneinstellung");
regGS("There was an error scheduling the $1 action on $2", "Fehler bei der Automatisierung von $1 am $2");
regGS("The action scheduled on $1 could not be deleted.", "Die Aktion vom $1 konnte nicht gelöscht werden");
?>
